/*
 * Copyright 2009-2012 forwardfire.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *   following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *   the following disclaimer in the documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.forwardfire.logstats.ejb.models;

import java.util.Date;

import net.forwardfire.vasc.annotations.VascDefaultValue;
import net.forwardfire.vasc.annotations.VascDisplayName;
import net.forwardfire.vasc.annotations.VascField;
import net.forwardfire.vasc.annotations.VascFieldOrder;
import net.forwardfire.vasc.annotations.VascFieldType;
import net.forwardfire.vasc.annotations.VascI18n;
import net.forwardfire.vasc.annotations.VascPrimaryKey;
import net.forwardfire.vasc.annotations.VascStyle;
import net.forwardfire.vasc.validators.VascObjectNotNull;
import net.forwardfire.vasc.validators.VascStringLength;

/**
 * Template class for common vasc annotations
 * 
 * @author Willem Cazander
 * @version 1.0 May 23, 2009
 */
abstract public class AbstractFieldTemplates {
	
	/**
	 * Template for id field.
	 */
    @VascI18n(name="generic.id.labelText",description="generic.id.toolTipText")
    @VascPrimaryKey
    @VascStyle(sizeList=50)
    @VascFieldOrder(orderIndex=0)
    @VascField(create=false,editReadOnly=true)
	abstract public Integer getId();
		
	/**
	 * Template for name field.
	 */
    @VascI18n(name="generic.name.labelText",description="generic.name.toolTipText")
    @VascDisplayName
    @VascObjectNotNull
    @VascStringLength(min=4,max=128)
    @VascStyle(sizeList=250,sizeEdit=40)
    @VascFieldOrder(orderIndex=1)
	abstract public String getName();

	/**
	 * Template for description field.
	 */
    @VascI18n(name="generic.description.labelText",description="generic.description.toolTipText")
    @VascFieldType(type="TextAreaField",properties={"editor.columns=40","editor.rows=5"})
    @VascField(list=false)
    @VascStringLength(min=8,max=4096)
    @VascObjectNotNull
    @VascFieldOrder(orderIndex=2)
	abstract public String getDescription();
	
	/**
	 * Template for active field.
	 */
	@VascI18n(name="generic.active.labelText",description="generic.active.toolTipText")
	@VascDefaultValue(value="true")
	@VascObjectNotNull
	@VascFieldOrder(orderIndex=4)
	abstract public Boolean getActive();
	
	/**
	 * Template for order number field.
	 */
	@VascI18n(name="generic.orderNumber.labelText",description="generic.orderNumber.toolTipText")
	@VascField(view=false)
	abstract public Integer getOrderNumber();

	/**
	 * Template for createdDate field.
	 */
	@VascI18n(name="generic.createdDate.labelText",description="generic.createdDate.toolTipText")
	@VascField(create=false,editReadOnly=true)
	@VascDefaultValue(value="now()")
	abstract public Date getCreatedDate();	
	
	/**
	 * Template for modifiedDate field.
	 */
	@VascI18n(name="generic.modifiedDate.labelText",description="generic.modifiedDate.toolTipText")
	@VascField(create=false,editReadOnly=true)
	@VascDefaultValue(value="now()")
	abstract public Date getModifiedDate();	
}