/*
 * Copyright 2009-2012 forwardfire.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *   following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *   the following disclaimer in the documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.forwardfire.logstats.ejb.models;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import net.forwardfire.vasc.annotations.VascDefaultValue;
import net.forwardfire.vasc.annotations.VascDisplayName;
import net.forwardfire.vasc.annotations.VascField;
import net.forwardfire.vasc.annotations.VascFieldTemplate;
import net.forwardfire.vasc.annotations.VascModelReference;

/**
 * LogValueLine
 *
 * @author Willem Cazander
 * @version 1.0 Jun 09, 2010
 */
@Entity
@Table(name = "log_value_line")
@SequenceGenerator(name="LOG_VALUE_LINE_ID_SEQ", sequenceName="log_value_line_id_seq",allocationSize=1)
@Cache(usage=CacheConcurrencyStrategy.NONE)
public class LogValueLine extends AbstractEntityBase {
	
	private static final long serialVersionUID = 10L;
	private Integer id = null;
	private Boolean active  = null;
	private LogHost logHost = null;
	private LogValue logValue = null;
	private LogLevel logLevel = null;
	private LogSource logSource = null;
	private String matchRegex = null;
	private String splitRegex = null;
	private Integer timeIndexNumber = null;
	private Integer valueIndexNumber = null;
	private Integer valueMinimal = null;
	private Date startDate = null;
	private Date stopDate = null;
	
	/**
	 * @return the id
	 */
	@Id
	@GeneratedValue(strategy=GenerationType.SEQUENCE,generator="LOG_VALUE_LINE_ID_SEQ")
	@Column(name="id",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Integer getId() {
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(Integer id) {
		this.id = id;
	}

	/**
	 * @return the active
	 */
	@Column(name="active",nullable=false)
	@VascFieldTemplate(templateClass=AbstractFieldTemplates.class)
	public Boolean getActive() {
		return active;
	}

	/**
	 * @param active the active to set
	 */
	public void setActive(Boolean active) {
		this.active = active;
	}

	/**
	 * @return the splitRegex
	 */
	@Column(name="split_regex",nullable=false)
	@VascDisplayName
	@VascDefaultValue(value="\\s")
	public String getSplitRegex() {
		return splitRegex;
	}

	/**
	 * @param splitRegex the splitRegex to set
	 */
	public void setSplitRegex(String splitRegex) {
		this.splitRegex = splitRegex;
	}
	
	/**
	 * @return the matchRegex
	 */
	@Column(name="match_regex",nullable=false)
	public String getMatchRegex() {
		return matchRegex;
	}

	/**
	 * @param matchRegex the matchRegex to set
	 */
	public void setMatchRegex(String matchRegex) {
		this.matchRegex = matchRegex;
	}

	/**
	 * @return the timeIndexNumber
	 */
	@Column(name="time_index_number",nullable=false)
	public Integer getTimeIndexNumber() {
		return timeIndexNumber;
	}

	/**
	 * @param timeIndexNumber the timeIndexNumber to set
	 */
	public void setTimeIndexNumber(Integer timeIndexNumber) {
		this.timeIndexNumber = timeIndexNumber;
	}

	/**
	 * @return the valueIndexNumber
	 */
	@Column(name="value_index_number",nullable=false)
	public Integer getValueIndexNumber() {
		return valueIndexNumber;
	}

	/**
	 * @param valueIndexNumber the valueIndexNumber to set
	 */
	public void setValueIndexNumber(Integer valueIndexNumber) {
		this.valueIndexNumber = valueIndexNumber;
	}

	/**
	 * @return the valueMinimal
	 */
	@Column(name="value_minimal",nullable=true)
	public Integer getValueMinimal() {
		return valueMinimal;
	}

	/**
	 * @param valueMinimal the valueMinimal to set
	 */
	public void setValueMinimal(Integer valueMinimal) {
		this.valueMinimal = valueMinimal;
	}

	/**
	 * @return the startDate
	 */
	@Column(name="start_date",nullable=true)
	public Date getStartDate() {
		return startDate;
	}

	/**
	 * @param startDate the startDate to set
	 */
	public void setStartDate(Date startDate) {
		this.startDate = startDate;
	}

	/**
	 * @return the stopDate
	 */
	@Column(name="stop_date",nullable=true)
	public Date getStopDate() {
		return stopDate;
	}

	/**
	 * @param stopDate the stopDate to set
	 */
	public void setStopDate(Date stopDate) {
		this.stopDate = stopDate;
	}

	
	/**
	 * @return the logHost
	 */
	@OneToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="log_host_id",nullable=true)
    @VascModelReference
	public LogHost getLogHost() {
		return logHost;
	}

	/**
	 * @param logHost the logHost to set
	 */
	public void setLogHost(LogHost logHost) {
		this.logHost = logHost;
	}

	/**
	 * @return the logValue
	 */
	@OneToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="log_value_id",nullable=false)
    @VascModelReference
    @VascField(edit=false,list=false)
	public LogValue getLogValue() {
		return logValue;
	}

	/**
	 * @param logValue the logValue to set
	 */
	public void setLogValue(LogValue logValue) {
		this.logValue = logValue;
	}
	
	/**
	 * @return the logLevel
	 */
	@OneToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="log_level_id",nullable=false)
    @VascModelReference
	public LogLevel getLogLevel() {
		return logLevel;
	}

	/**
	 * @param logLevel the logLevel to set
	 */
	public void setLogLevel(LogLevel logLevel) {
		this.logLevel = logLevel;
	}

	/**
	 * @return the logSource
	 */
	@OneToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="log_source_id",nullable=false)
    @VascModelReference
	public LogSource getLogSource() {
		return logSource;
	}

	/**
	 * @param logSource the logSource to set
	 */
	public void setLogSource(LogSource logSource) {
		this.logSource = logSource;
	}
}