package net.forwardfire.logstats.jboss.log4j;

import org.apache.log4j.AppenderSkeleton;
import org.apache.log4j.spi.LoggingEvent;
import org.jboss.logging.Logger;

/**
 * Appends log4j messages to the logService MBean
 * 
 * @author Willem Cazander
 * @version 1.0 Jun 09, 2010
 */
public class DataSourceLog4jAppender extends AppenderSkeleton {

	private DataSourceLogService logService = null;
	private Logger logger = Logger.getLogger(DataSourceLog4jAppender.class.getName());
			
	/**
	 * constructor
	 * @throws Exception 
	 */
	public DataSourceLog4jAppender(DataSourceLogService logService) {
		super();
		if (logService==null) {
			throw new NullPointerException("Can't start with null logService.");
		}
		this.logService=logService;
		setName(logService.getLog4jAppenderName());
		logger.info("Created DataSourceLog4jAppender with name: "+getName());
	}


	/**
	 * Closes this appender privately.
	 */
	public void shutdown() {
		logService = null;
		logger.info("Closed DataSourceLog4jAppender with name: "+getName());		
	}
	
	/**
	 * Closes this appender but is left empty because of fake call.
	 */
	public void close() {
	}
	
	/**
	 * Put LoggingEvent in queue for processing.
	 */
	public void append(LoggingEvent event) {
		if (logService==null) {
			return;
		}
		try {
			logService.putLoggingEvent(event);
		} catch (InterruptedException e) {
			// we don't log in appender, in case of loop.
		}
	}
	
	/**
	 * DataSourceLog4jAppender don't require a layout.
	 */
	public boolean requiresLayout() {
		return false;
	}
}