/*
 * Copyright 2009-2012 forwardfire.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *   following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *   the following disclaimer in the documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.forwardfire.logstats.web.beans;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;

import javax.ejb.EJB;
import javax.faces.model.SelectItem;

import net.forwardfire.logstats.ejb.models.LogData;
import net.forwardfire.logstats.ejb.services.LoginManagerRemote;
import net.forwardfire.logstats.ejb.services.ServerManagerRemote;

/**
 * 
 * @author Willem Cazander
 * @version 1.0 Jul 06, 2010
 */
public class RealTimeController implements Serializable {

	private static final long serialVersionUID = 1L;

	private boolean pollEnabled = true;
	private boolean reversedTail = false;
	private String filterHostname = null;
	private Integer filterLevel = null;
	private String filterRegex = null;
	private Pattern filterRegexPattern = null;
	private int messageRows = 40;
	private int messageCols = 260;
	
	@EJB()
	LoginManagerRemote loginManager;

	@EJB()
	ServerManagerRemote serverManager;
	
	private StringBuilder getStartBuffer(List<LogData> data) {
		StringBuilder buf = new StringBuilder();
		int size = data.size();
		for (int i=0;i<size;i++) {
			LogData d = data.get(i);
			if (filterLevel!=null && filterLevel.equals(d.getLogLevel())==false) {
				continue;
			}
			if (filterHostname!=null && filterHostname.equals(d.getLogLevel())==false) {
				continue;
			}
			if (filterRegexPattern!=null && filterRegexPattern.matcher(d.getMessage()).matches()==false) {
				continue;
			}
			buf.append(d.getLogDate());
			buf.append(' ');
			buf.append(d.getHostname());
			buf.append(' ');
			buf.append(d.getLogLevel());
			buf.append(' ');
			buf.append(d.getSource());
			buf.append(' ');
			buf.append(d.getMessage());
			buf.append('\n');
		}
		return buf;
	}
	
	public String getMessageLogData() {
		List<LogData> data = serverManager.getRealTimeLogData();
		if (reversedTail) {
			Collections.reverse(data);
		}
		StringBuilder buf = getStartBuffer(data);
		return buf.toString();
	}
	
	public void setMessageLogData(String voidData) {
		// method so jsf is oke.
	}
	
	/**
	 * @return the pollEnabled
	 */
	public boolean isPollEnabled() {
		return pollEnabled;
	}

	/**
	 * @param pollEnabled the pollEnabled to set
	 */
	public void setPollEnabled(boolean pollEnabled) {
		this.pollEnabled = pollEnabled;
	}

	/**
	 * @return the reversedTail
	 */
	public boolean isReversedTail() {
		return reversedTail;
	}

	/**
	 * @param reversedTail the reversedTail to set
	 */
	public void setReversedTail(boolean reversedTail) {
		this.reversedTail = reversedTail;
	}

	/**
	 * @return the filterHostname
	 */
	public String getFilterHostname() {
		return filterHostname;
	}

	/**
	 * @param filterHostname the filterHostname to set
	 */
	public void setFilterHostname(String filterHostname) {
		this.filterHostname = filterHostname;
	}

	/**
	 * @return the filterLevel
	 */
	public Integer getFilterLevel() {
		return filterLevel;
	}

	/**
	 * @param filterLevel the filterLevel to set
	 */
	public void setFilterLevel(Integer filterLevel) {
		this.filterLevel = filterLevel;
	}

	/**
	 * @return the filterRegex
	 */
	public String getFilterRegex() {
		return filterRegex;
	}

	/**
	 * @param filterRegex the filterRegex to set
	 */
	public void setFilterRegex(String filterRegex) {
		this.filterRegex = filterRegex;
		if (filterRegex!=null && filterRegex.isEmpty()==false) {
			try {
				filterRegexPattern = Pattern.compile(filterRegex);
			} catch (PatternSyntaxException pse) {
				filterRegexPattern = null; //  remove old regex
				pse.printStackTrace();
			}
		} else {
			filterRegexPattern = null;
		}
	}

	/**
	 * @return the messageRows
	 */
	public int getMessageRows() {
		return messageRows;
	}

	/**
	 * @param messageRows the messageRows to set
	 */
	public void setMessageRows(int messageRows) {
		this.messageRows = messageRows;
	}

	/**
	 * @return the messageCols
	 */
	public int getMessageCols() {
		return messageCols;
	}

	/**
	 * @param messageCols the messageCols to set
	 */
	public void setMessageCols(int messageCols) {
		this.messageCols = messageCols;
	}

	public List<SelectItem> getMessageRowsSelectItems() {
		List<SelectItem> result = new ArrayList<SelectItem>(5);
		result.add(new SelectItem(10, "10"));
		result.add(new SelectItem(20, "20"));
		result.add(new SelectItem(40, "40"));
		result.add(new SelectItem(60, "60"));
		result.add(new SelectItem(80, "80"));
		result.add(new SelectItem(102, "100")); // to remove scroll bar 102, buf is 100
		return result;
	}
	
	public List<SelectItem> getMessageColsSelectItems() {
		List<SelectItem> result = new ArrayList<SelectItem>(5);
		result.add(new SelectItem(80, "80"));
		result.add(new SelectItem(120, "120"));
		result.add(new SelectItem(150, "150"));
		result.add(new SelectItem(200, "200"));
		result.add(new SelectItem(240, "240"));
		result.add(new SelectItem(260, "260"));
		result.add(new SelectItem(280, "280"));
		result.add(new SelectItem(300, "300"));
		return result;
	}
}